@@ -201,14 +201,18 @@ class interface(abstract_instrument_interface.abstract_interface):
             return False
         return True
     
-    def read_sensitivity(self):
-        self.logger.info(f"Reading current sensitivity from device {self.connected_device_name}...") 
+    def read_sensitivity(self, log= True):
+        #when log = False, the message regarding the read of sensitivities is not added to the logs
+        #this is useful to avoid excessively polluting the logs when sensitivty is changed very often automatically
+        if log:
+            self.logger.info(f"Reading current sensitivity from device {self.connected_device_name}...") 
         self.sensitivity = self.instrument.sensitivity
         if self.sensitivity == None:
             self.logger.error(f"An error occurred while reading the sensitivity from this device.")
             return
         self.gui.combo_Sensitivities.setCurrentIndex(self.sensitivity)
-        self.logger.info(f"Current sensitivity is {self.sensitivities[self.sensitivity]} (index={self.sensitivity})...") 
+        if log:
+            self.logger.info(f"Current sensitivity is {self.sensitivities[self.sensitivity]} (index={self.sensitivity})...") 
         
     def set_sensitivity(self,s, log = True): 
         #when log = False, the message regarding the change of sensitivities is not added to the logs
@@ -219,7 +223,8 @@ class interface(abstract_instrument_interface.abstract_interface):
             self.logger.info(f"Setting sensitivity to {self.sensitivities[s]}  (index={s})...")
         try: 
             self.instrument.sensitivity = s #set sensitivity
-            snew = self.instrument.sensitivity #read again sensitivity to confirm that it changed
+            self.read_sensitivity(log = log) #read again sensitivity to confirm that it changed and to make sure that combobox is updated
+            snew = self.sensitivity
             if snew == s:
                 if log:
                     self.logger.info(f"Sensitivity changed to {self.sensitivities[s]} (old value was {self.sensitivities[self.sensitivity]}).")
